# py-tacotree

Toolbox for data processing pipelines.

Knowledge of PyTorch is required. See [debug/example_model_sequential.py](debug/example_model_sequential.py) for how to
create a model in tacotree.
